<?php 

namespace Drupal\content_reporting_charts\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\charts\ChartsSettingsInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Database\Connection;

class ContentReportingChartsController extends ControllerBase {

  protected $database;
  protected $chartsSettings;

  public function __construct(Connection $database, ChartsSettingsInterface $charts_settings) {
    $this->database = $database;
    $this->chartsSettings = $charts_settings;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('charts.settings')
    );
  }

  public function dashboard() {
    // Esempio di query per ottenere i dati per i grafici.
    $query = $this->database->select('content_reporting_reports', 'r')
      ->fields('r', ['title', 'views', 'gdpr_consent'])
      ->execute()
      ->fetchAll();

    // Prepara i dati per il grafico.
    $labels = [];
    $views = [];
    $consents = [];

    foreach ($query as $result) {
      $labels[] = $result->title;
      $views[] = $result->views;
      $consents[] = $result->gdpr_consent;
    }

    // Configurazione per il grafico delle views.
    $chart = [
      '#type' => 'chart',
      '#chart_type' => 'bar',
      '#title' => 'Views and GDPR Consents per Page',
      '#labels' => $labels,
      '#data' => [
        'Views' => $views,
        'GDPR Consents' => $consents,
      ],
      '#options' => [
        'colors' => ['Views' => '#2E86C1', 'GDPR Consents' => '#28B463'],
      ],
    ];

    return [
      '#theme' => 'content_reporting_charts_dashboard',
      '#chart' => $chart,
    ];
  }
}
